@@ -1,7 +1,7 @@
 /** @file expand.cc
  * @brief Set the query expansion scheme for Omega
  */
-/* Copyright (C) 2009,2013,2014 Olly Betts
+/* Copyright (C) 2009,2013,2014,2015 Olly Betts
  * Copyright (C) 2013 Aarsh Shah
  *
  * This program is free software; you can redistribute it and/or modify
@@ -56,7 +56,9 @@ double_param(const char ** p, double * ptr_val)
     return true;
 }
 
+#if !XAPIAN_AT_LEAST(1,3,2)
 double expand_param_k = 1.0;
+#endif
 
 void
 set_expansion_scheme(Xapian::Enquire & enq, const map<string, string> & opt)
@@ -67,12 +69,42 @@ set_expansion_scheme(Xapian::Enquire & enq, const map<string, string> & opt)
     const string & scheme = i->second;
     if (scheme.empty()) return;
 
+#if XAPIAN_AT_LEAST(1,3,2)
+    if (startswith(scheme, "trad")) {
+	const char *p = scheme.c_str() + 4;
+	if (*p == '\0') {
+	    enq.set_expansion_scheme("trad");
+	    return;
+	}
+	if (C_isspace(*p)) {
+	    // Initialise k just to silence compiler warning.
+	    double k = 0.0;
+	    if (!double_param(&p, &k))
+		parameter_error("Parameter k is invalid", scheme);
+	    if (*p)
+		parameter_error("Extra data after first parameter", scheme);
+	    enq.set_expansion_scheme("trad", k);
+	    return;
+	}
+    }
+
+    if (startswith(scheme, "bo1")) {
+	const char *p = scheme.c_str() + 3;
+	if (*p == '\0') {
+	    enq.set_expansion_scheme("bo1");
+	    return;
+	}
+	if (C_isspace(*p)) {
+	    throw "No parameters are required for BO1";
+	}
+    }
+#else
     if (startswith(scheme, "trad")) {
 	const char *p = scheme.c_str() + 4;
 	if (*p == '\0') {
 	    return;
 	}
-	if (C_isspace((unsigned char)*p)) {
+	if (C_isspace(*p)) {
 	    // Initialise k just to silence compiler warning.
 	    double k = 0.0;
 	    if (!double_param(&p, &k))
@@ -85,6 +117,7 @@ set_expansion_scheme(Xapian::Enquire & enq, const map<string, string> & opt)
 	    return;
 	}
     }
+#endif
 
     throw "Unknown $opt{expansion} setting: " + scheme;
 }
