@@ -190,7 +190,7 @@ parse_index_script(const string &filename)
 	j = i;
 	while (j != s.end()) {
 	    i = find_if(j, s.end(), p_notalpha);
-	    string action = s.substr(j - s.begin(), i - j);
+	    string action(s, j - s.begin(), i - j);
 	    Action::type code = Action::BAD;
 	    enum {NO, OPT, YES} arg = NO;
 	    bool takes_integer_argument = false;
@@ -303,18 +303,6 @@ parse_index_script(const string &filename)
 		}
 		switch (code) {
 		    case Action::INDEX:
-			if (val == "nopos") {
-			    // INDEX used to take an optional argument which
-			    // could be "nopos" to mean the same that
-			    // INDEXNOPOS now does.  FIXME:1.3.0 remove this
-			    // error eventually
-			    cerr << filename << ':' << line_no
-				 << ": Support for 'index=nopos' has been "
-				    "removed - use 'indexnopos' instead"
-				 << endl;
-			    exit(1);
-			}
-			/* FALLTHRU */
 		    case Action::INDEXNOPOS:
 			actions.push_back(Action(code, val, weight));
 			useless_weight_pos = string::npos;
@@ -458,8 +446,8 @@ index_file(const char *fname, istream &stream,
 		    "in this line" << endl;
 		// FIXME: die or what?
 	    }
-	    string field = line.substr(0, eq);
-	    string value = line.substr(eq + 1);
+	    string field(line, 0, eq);
+	    string value(line, eq + 1, string::npos);
 	    while (getline(stream, line)) {
 		++line_no;
 		if (line.empty() || line[0] != '=') break;
